==> inv-api-1.3.8.45-20231124.065949-1-sources.jar: com/elitesland/inv/provider/InvStkCardProvider.java <==
package com.elitesland.inv.provider;

import com.elitesland.inv.Application;
import com.elitesland.inv.dto.card.CardLockRpcDTO;
import com.elitesland.inv.dto.card.CardQueryRpcDTO;
import com.elitesland.inv.dto.card.CardUseRpcDTO;
import com.elitesland.inv.dto.card.InvStkCardRpcDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@Validated
@FeignClient(name = Application.NAME,path = Application.PATH + InvStkCardProvider.PATH)
public interface InvStkCardProvider {

    String PATH = "/invCard";

    /**
     * 查询卡号
     * @param cardQueryRpcDTO
     * @return
     */
    @PostMapping("/queryCardNo")
    List<String> queryCardNo(@RequestBody CardQueryRpcDTO cardQueryRpcDTO);

    /**
     * 查询
     * @param cardQueryRpcDTO
     * @return
     */
    @PostMapping("/query")
    List<InvStkCardRpcDTO> query(@RequestBody CardQueryRpcDTO cardQueryRpcDTO);

    /**
     * 领用
     * @param cardUseRpcDTO
     */
    @PostMapping("/use")
    void use(@RequestBody CardUseRpcDTO cardUseRpcDTO);

    /**
     * 归还
     * @param cardUseRpcDTO
     */
    @PostMapping("/rtn")
    void rtn(@RequestBody CardUseRpcDTO cardUseRpcDTO);

    /**
     * 卡券占用。卡券领用单、归还单，草稿状态传入卡号占用
     *
     * @param cardLockRpcDTO
     */
    @PostMapping("/lock")
    void lock(@RequestBody CardLockRpcDTO cardLockRpcDTO);

    /**
     * 卡券释放占用。卡券领用单、归还单
     * @param cardLockRpcDTO
     */
    @PostMapping("/unlock")
    void unlock(@RequestBody CardLockRpcDTO cardLockRpcDTO);

    /**
     * 卡券释放占用。卡券领用单、归还单，整单释放，不指定具体卡号，释放单据占用的所有卡券
     * @param lockDocNo
     */
    @PostMapping("/unlock/all")
    void unlock(@RequestParam("lockDocNo") String lockDocNo);
}

==> inv-api-1.3.8.47-20231128.012815-1-sources.jar: com/elitesland/inv/provider/InvStkCardProvider.java <==
package com.elitesland.inv.provider;

import com.elitesland.inv.Application;
import com.elitesland.inv.dto.card.CardLockRpcDTO;
import com.elitesland.inv.dto.card.CardQueryRpcDTO;
import com.elitesland.inv.dto.card.CardUseRpcDTO;
import com.elitesland.inv.dto.card.InvStkCardRpcDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@Validated
@FeignClient(name = Application.NAME,path = Application.PATH + InvStkCardProvider.PATH)
public interface InvStkCardProvider {

    String PATH = "/invCard";

    /**
     * 查询卡号
     * @param cardQueryRpcDTO
     * @return
     */
    @PostMapping("/queryCardNo")
    List<String> queryCardNo(@RequestBody CardQueryRpcDTO cardQueryRpcDTO);

    /**
     * 查询
     * @param cardQueryRpcDTO
     * @return
     */
    @PostMapping("/query")
    List<InvStkCardRpcDTO> query(@RequestBody CardQueryRpcDTO cardQueryRpcDTO);

    /**
     * 领用
     * @param cardUseRpcDTO
     */
    @PostMapping("/use")
    void use(@RequestBody CardUseRpcDTO cardUseRpcDTO);

    /**
     * 归还
     * @param cardUseRpcDTO
     */
    @PostMapping("/rtn")
    void rtn(@RequestBody CardUseRpcDTO cardUseRpcDTO);

    /**
     * 卡券占用。卡券领用单、归还单，草稿状态传入卡号占用
     *
     * @param cardLockRpcDTO
     */
    @PostMapping("/lock")
    void lock(@RequestBody CardLockRpcDTO cardLockRpcDTO);

    /**
     * 卡券释放占用。卡券领用单、归还单
     * @param cardLockRpcDTO
     */
    @PostMapping("/unlock")
    void unlock(@RequestBody CardLockRpcDTO cardLockRpcDTO);

    /**
     * 卡券释放占用。卡券领用单、归还单、卡券发货单、卡券退货入库单，整单释放，不指定具体卡号，释放单据占用的所有卡券
     * @param lockDocNo
     */
    @PostMapping("/unlock/all")
    void unlock(@RequestParam("lockDocNo") String lockDocNo);

    /**
     * 销售出库
     * @param lockDocNo 锁定卡券的单号，卡券销售订单单号
     * @param outDocNo 卡券发货单单号
     */
    @PostMapping("/saleOut")
    void saleOut(@RequestParam("lockDocNo") String lockDocNo, @RequestParam("outDocNo") String outDocNo);

    /**
     * 退货入库
     * @param lockDocNo 锁定卡券的退货入库订单单号
     * @param rtnInDocNo 卡券退货入库单单号
     */
    @PostMapping("/rtnIn")
    void rtnIn(@RequestParam("lockDocNo") String lockDocNo, @RequestParam("rtnInDocNo") String rtnInDocNo);
}
